alchy
*****

|version| |travis| |coveralls| |license|

A SQLAlchemy extension for its declarative ORM that provides enhancements for model classes, queries, and sessions.

Links
=====

- Project: https://github.com/dgilland/alchy
- Documentation: http://alchy.readthedocs.org
- PyPi: https://pypi.python.org/pypi/alchy/
- TravisCI: https://travis-ci.org/dgilland/alchy


.. |version| image:: http://img.shields.io/pypi/v/alchy.svg?style=flat-square
    :target: https://pypi.python.org/pypi/alchy/

.. |travis| image:: http://img.shields.io/travis/dgilland/alchy/master.svg?style=flat-square
    :target: https://travis-ci.org/dgilland/alchy

.. |coveralls| image:: http://img.shields.io/coveralls/dgilland/alchy/master.svg?style=flat-square
    :target: https://coveralls.io/r/dgilland/alchy

.. |license| image:: http://img.shields.io/pypi/l/alchy.svg?style=flat-square
    :target: https://pypi.python.org/pypi/alchy/
